@@ -6,15 +6,15 @@ OC.L10N.register(
     "Work" : "Labour",
     "Personal" : "Personel",
     "Mail" : "Postel",
+    "Save" : "Enrollañ",
+    "Connect" : "Kenstagañ",
+    "Password required" : "Ger-tremen ret",
     "Name" : "Anv",
     "Password" : "Ger-tremen",
     "None" : "Hini ebet",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
     "SMTP Password" : "Ger-tremen SMTP",
-    "Save" : "Enrollañ",
-    "Connect" : "Kenstagañ",
-    "Password required" : "Ger-tremen ret",
     "Change name" : "Cheñch env",
     "Cancel" : "Arrest",
     "Accounts" : "Kontoù",
@@ -43,18 +43,18 @@ OC.L10N.register(
     "Show images" : "Diskouzh ar skeudennoù",
     "Message frame" : "Fram kemenadenn",
     "Move" : "Diplasañ",
-    "Quota" : "Quota",
-    "Remove account" : "Lemel ar c'hont",
     "Loading …" : "O Kargañ ...",
+    "Remove account" : "Lemel ar c'hont",
+    "Quota" : "Quota",
     "Rename" : "Adenvel",
     "Clear cache" : "Gwalc'hiñ ar c'hache",
-    "Retry" : "Klaskit en dro",
     "Reply" : "Respont",
+    "Retry" : "Klaskit en dro",
     "Add" : "Ouzhpennañ",
+    "Clear" : "Netaat",
     "Close" : "Serriñ",
     "Date" : "Deiz",
     "Tags" : "Klavioù",
-    "Clear" : "Netaat",
     "Actions" : "Oberoù",
     "Client ID" : "ID kliant",
     "User" : "Implijer",
@@ -65,7 +65,6 @@ OC.L10N.register(
     "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Unselect" : "Dizibab"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
