@@ -546,6 +546,7 @@ OC.L10N.register(
     "Could not load your message thread" : "Nepodařilo se načíst vlákno s danou zprávou",
     "The thread doesn't exist or has been deleted" : "Vlákno neexistuje nebo bylo smazáno",
     "Email was not able to be opened" : "E-mail nebylo možné otevřít",
+    "Print" : "Tisk",
     "Loading thread" : "Načítání vlákna",
     "Not found" : "Nenalezeno",
     "Encrypted & verified " : "Šifrováno a ověřen",
@@ -783,6 +784,10 @@ OC.L10N.register(
     "Redirect" : "Přesměrovat",
     "The link leads to %s" : "Odkaz vede na %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Pokud nechcete tuto stránku navštívit, můžete se vrátit do <a href=\"%s\">e-mailu</a>.",
-    "Continue to %s" : "Pokračovat na %s"
+    "Continue to %s" : "Pokračovat na %s",
+    "Subject: " : "Předmět: ",
+    "From: " : "Od: ",
+    "Date: " : "Datum: ",
+    "To : " : "Pro: "
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
