@@ -12,6 +12,8 @@ OC.L10N.register(
     "To Do" : "Tegemiseks",
     "Later" : "Hiljem",
     "Mail" : "Kirjad",
+    "Mail Application" : "E-posti rakendus",
+    "Mail connection performance" : "E-postiteenuse ühenduse jõudlus",
     "Connecting" : "Ühendamine",
     "Save" : "Salvesta",
     "Connect" : "Ühenda",
@@ -58,7 +60,13 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "Vali fail, mida manustada",
     "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
     "Confirm" : "Kinnita",
+    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
+    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
+    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
+    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
+    "This summary was AI generated" : "Koond on loodud tehisaru poolt",
     "Favorite" : "Lemmik",
+    "Unread" : "Lugemata",
     "Read" : "Lugemine",
     "Edit tags" : "Muuda silte",
     "More actions" : "Täiendavad tegevused",
@@ -83,6 +91,7 @@ OC.L10N.register(
     "Comment" : "Kommentaar",
     "Accept" : "Nõustu",
     "Decline" : "Keeldu",
+    "More options" : "Täiendavad valikud",
     "Remove" : "Eemalda",
     "email" : "e-post",
     "Other" : "Muu",
@@ -113,6 +122,8 @@ OC.L10N.register(
     "Retry" : "Proovi uuesti",
     "Sending …" : "Saadan ...",
     "Message" : "Sõnum",
+    "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
+    "Hide suspicious links" : "Peida kahtlased lingid",
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Add" : "Lisa",
     "Show less" : "Näita vähem",
@@ -123,6 +134,7 @@ OC.L10N.register(
     "Tags" : "Sildid",
     "Select tags" : "Vali sildid",
     "Last 7 days" : "Viimase 7 päeva jooksul",
+    "Enable sieve filter" : "Lülita sieve filter sisse",
     "Custom" : "Kohandatud",
     "Tag already exists" : "Silt on juba olemas",
     "Print" : "Trüki",
@@ -130,6 +142,10 @@ OC.L10N.register(
     "Please wait for the message to load" : "Palun oota, kuni e-kirja laadimine on lõppenud",
     "Mark as unread" : "Märgi mitteloetuks",
     "Mark as read" : "Märgi loetuks",
+    "Please select languages to translate to and from" : "Palun vali keeled, mille vahel tahad tõlkida",
+    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
+    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
+    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
     "Translate message" : "Tõlgi e-kiri",
     "Source language to translate from" : "Tõlke lähtekeel",
     "Translate from" : "Lähtekeel tõlkimisel",
@@ -138,9 +154,23 @@ OC.L10N.register(
     "Translating" : "Tõlkimisel",
     "Copy translated text" : "Kopeeri tõlgitud tekst",
     "Delete action" : "Kustuta tegevus",
+    "Delete filter" : "Kustuta filter",
+    "Are you sure to delete the mail filter?" : "Kas sa oled kindel, et soovid selle e-postifiltri kustutada?",
+    "New filter" : "Uus filter",
+    "Filter saved" : "Filter on salvestatud",
+    "Could not save filter" : "Filtri salvestamine ei õnnestunud",
+    "Filter deleted" : "Filter on kustutatud",
+    "Could not delete filter" : "Filtri kustutamine on õnnestunud",
+    "Filter is active" : "Filter on kasutusel",
+    "Filter is not active" : "Filter pole kasutusel",
     "Operator" : "Operaator",
+    "Delete test" : "Kustuta test",
+    "Tests" : "Testid",
+    "New test" : "Uus test",
     "Actions" : "Tegevused",
+    "New action" : "Uus tegevus",
     "Priority" : "Prioriteet",
+    "Save filter" : "Salvesta filter",
     "Reset" : "Lähtesta",
     "Client ID" : "Kliendi ID",
     "Client secret" : "Kliendi salasõna",
@@ -189,6 +219,10 @@ OC.L10N.register(
     "Error loading message" : "Tõrge kirja laadimisel",
     "Forwarding to %s" : "Edasta %s",
     "Redirect" : "Suunamine",
-    "Continue to %s" : "Jätka siit: %s"
+    "Continue to %s" : "Jätka siit: %s",
+    "Subject: " : "Teema:",
+    "From: " : "Saatja:",
+    "Date: " : "Kuupäev:",
+    "To : " : "Saaja:"
 },
 "nplurals=2; plural=(n != 1);");
